@@ -3,7 +3,7 @@ select
     region,
     sum(total_sales) as total_sales
 
-from { csv("data/sales.csv") }
+from { csv("data/sales.csv", ";") }
 
 group by
     year_month,
